# coding: utf-8

"""
    Amber API Server

    Boon Logic Amber API server

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PostDataRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'str',
        'save_image': 'bool'
    }

    attribute_map = {
        'data': 'data',
        'save_image': 'saveImage'
    }

    def __init__(self, data=None, save_image=True):
        """PostDataRequest - a model defined in Swagger"""
        self._data = None
        self._save_image = None
        self.discriminator = None
        self.data = data
        if save_image is not None:
            self.save_image = save_image

    @property
    def data(self):
        """Gets the data of this PostDataRequest.

        Data as a flat list of comma-separated values. The number of values sent must be a multiple of the number of features in the configuration.

        :return: The data of this PostDataRequest.
        :rtype: str
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this PostDataRequest.

        Data as a flat list of comma-separated values. The number of values sent must be a multiple of the number of features in the configuration.

        :param data: The data of this PostDataRequest.
        :type: str
        """
        if data is None:
            raise ValueError("Invalid value for `data`, must not be `None`")

        self._data = data

    @property
    def save_image(self):
        """Gets the save_image of this PostDataRequest.

        If false, saved model image will not be updated on this request. Applies only to on-premises deployments.

        :return: The save_image of this PostDataRequest.
        :rtype: bool
        """
        return self._save_image

    @save_image.setter
    def save_image(self, save_image):
        """Sets the save_image of this PostDataRequest.

        If false, saved model image will not be updated on this request. Applies only to on-premises deployments.

        :param save_image: The save_image of this PostDataRequest.
        :type: bool
        """

        self._save_image = save_image

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PostDataRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostDataRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
